@@ -243,6 +243,7 @@ __all__ = (
     "InterfaceProtocolTypeType",
     "Ipv6SupportValueType",
     "KeyPairExistsWaiterName",
+    "KeyTypeType",
     "LaunchTemplateErrorCodeType",
     "LaunchTemplateHttpTokensStateType",
     "LaunchTemplateInstanceMetadataEndpointStateType",
@@ -1156,6 +1157,7 @@ InterfacePermissionTypeType = Literal["EIP-ASSOCIATE", "INSTANCE-ATTACH"]
 InterfaceProtocolTypeType = Literal["GRE", "VLAN"]
 Ipv6SupportValueType = Literal["disable", "enable"]
 KeyPairExistsWaiterName = Literal["key_pair_exists"]
+KeyTypeType = Literal["ed25519", "rsa"]
 LaunchTemplateErrorCodeType = Literal[
     "launchTemplateIdDoesNotExist",
     "launchTemplateIdMalformed",
